@@ -16,32 +16,45 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.bigquery_data_exchange_v1beta1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.bigquery_data_exchange_v1beta1.services.analytics_hub_service import (
-    pagers,
-)
-from google.cloud.bigquery_data_exchange_v1beta1.types import dataexchange
 from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
-from .transports.base import AnalyticsHubServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import AnalyticsHubServiceGrpcAsyncIOTransport
+
+from google.cloud.bigquery_data_exchange_v1beta1.services.analytics_hub_service import (
+    pagers,
+)
+from google.cloud.bigquery_data_exchange_v1beta1.types import dataexchange
+
 from .client import AnalyticsHubServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, AnalyticsHubServiceTransport
+from .transports.grpc_asyncio import AnalyticsHubServiceGrpcAsyncIOTransport
 
 
 class AnalyticsHubServiceAsyncClient:
@@ -178,9 +191,9 @@ class AnalyticsHubServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, AnalyticsHubServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the analytics hub service client.
@@ -224,11 +237,11 @@ class AnalyticsHubServiceAsyncClient:
 
     async def list_data_exchanges(
         self,
-        request: Union[dataexchange.ListDataExchangesRequest, dict] = None,
+        request: Optional[Union[dataexchange.ListDataExchangesRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDataExchangesAsyncPager:
         r"""Lists all data exchanges in a given project and
@@ -262,7 +275,7 @@ class AnalyticsHubServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListDataExchangesRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListDataExchangesRequest, dict]]):
                 The request object. Message for requesting the list of
                 data exchanges.
             parent (:class:`str`):
@@ -340,11 +353,11 @@ class AnalyticsHubServiceAsyncClient:
 
     async def list_org_data_exchanges(
         self,
-        request: Union[dataexchange.ListOrgDataExchangesRequest, dict] = None,
+        request: Optional[Union[dataexchange.ListOrgDataExchangesRequest, dict]] = None,
         *,
-        organization: str = None,
+        organization: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOrgDataExchangesAsyncPager:
         r"""Lists all data exchanges from projects in a given
@@ -378,7 +391,7 @@ class AnalyticsHubServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListOrgDataExchangesRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListOrgDataExchangesRequest, dict]]):
                 The request object. Message for requesting the list of
                 data exchanges from projects in an organization and
                 location.
@@ -461,11 +474,11 @@ class AnalyticsHubServiceAsyncClient:
 
     async def get_data_exchange(
         self,
-        request: Union[dataexchange.GetDataExchangeRequest, dict] = None,
+        request: Optional[Union[dataexchange.GetDataExchangeRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.DataExchange:
         r"""Gets the details of a data exchange.
@@ -497,7 +510,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.GetDataExchangeRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.GetDataExchangeRequest, dict]]):
                 The request object. Message for getting a data exchange.
             name (:class:`str`):
                 Required. The resource name of the data exchange. e.g.
@@ -565,12 +578,12 @@ class AnalyticsHubServiceAsyncClient:
 
     async def create_data_exchange(
         self,
-        request: Union[dataexchange.CreateDataExchangeRequest, dict] = None,
+        request: Optional[Union[dataexchange.CreateDataExchangeRequest, dict]] = None,
         *,
-        parent: str = None,
-        data_exchange: dataexchange.DataExchange = None,
+        parent: Optional[str] = None,
+        data_exchange: Optional[dataexchange.DataExchange] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.DataExchange:
         r"""Creates a new data exchange.
@@ -607,7 +620,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.CreateDataExchangeRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.CreateDataExchangeRequest, dict]]):
                 The request object. Message for creating a data
                 exchange.
             parent (:class:`str`):
@@ -685,12 +698,12 @@ class AnalyticsHubServiceAsyncClient:
 
     async def update_data_exchange(
         self,
-        request: Union[dataexchange.UpdateDataExchangeRequest, dict] = None,
+        request: Optional[Union[dataexchange.UpdateDataExchangeRequest, dict]] = None,
         *,
-        data_exchange: dataexchange.DataExchange = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        data_exchange: Optional[dataexchange.DataExchange] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.DataExchange:
         r"""Updates an existing data exchange.
@@ -725,7 +738,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.UpdateDataExchangeRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.UpdateDataExchangeRequest, dict]]):
                 The request object. Message for updating a data
                 exchange.
             data_exchange (:class:`google.cloud.bigquery_data_exchange_v1beta1.types.DataExchange`):
@@ -807,11 +820,11 @@ class AnalyticsHubServiceAsyncClient:
 
     async def delete_data_exchange(
         self,
-        request: Union[dataexchange.DeleteDataExchangeRequest, dict] = None,
+        request: Optional[Union[dataexchange.DeleteDataExchangeRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an existing data exchange.
@@ -840,7 +853,7 @@ class AnalyticsHubServiceAsyncClient:
                 await client.delete_data_exchange(request=request)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.DeleteDataExchangeRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.DeleteDataExchangeRequest, dict]]):
                 The request object. Message for deleting a data
                 exchange.
             name (:class:`str`):
@@ -898,11 +911,11 @@ class AnalyticsHubServiceAsyncClient:
 
     async def list_listings(
         self,
-        request: Union[dataexchange.ListListingsRequest, dict] = None,
+        request: Optional[Union[dataexchange.ListListingsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListListingsAsyncPager:
         r"""Lists all listings in a given project and location.
@@ -935,7 +948,7 @@ class AnalyticsHubServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListListingsRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListListingsRequest, dict]]):
                 The request object. Message for requesting the list of
                 listings.
             parent (:class:`str`):
@@ -1013,11 +1026,11 @@ class AnalyticsHubServiceAsyncClient:
 
     async def get_listing(
         self,
-        request: Union[dataexchange.GetListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.GetListingRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.Listing:
         r"""Gets the details of a listing.
@@ -1049,7 +1062,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.GetListingRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.GetListingRequest, dict]]):
                 The request object. Message for getting a listing.
             name (:class:`str`):
                 Required. The resource name of the listing. e.g.
@@ -1118,12 +1131,12 @@ class AnalyticsHubServiceAsyncClient:
 
     async def create_listing(
         self,
-        request: Union[dataexchange.CreateListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.CreateListingRequest, dict]] = None,
         *,
-        parent: str = None,
-        listing: dataexchange.Listing = None,
+        parent: Optional[str] = None,
+        listing: Optional[dataexchange.Listing] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.Listing:
         r"""Creates a new listing.
@@ -1160,7 +1173,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.CreateListingRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.CreateListingRequest, dict]]):
                 The request object. Message for creating a listing.
             parent (:class:`str`):
                 Required. The parent resource path of the listing. e.g.
@@ -1236,12 +1249,12 @@ class AnalyticsHubServiceAsyncClient:
 
     async def update_listing(
         self,
-        request: Union[dataexchange.UpdateListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.UpdateListingRequest, dict]] = None,
         *,
-        listing: dataexchange.Listing = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        listing: Optional[dataexchange.Listing] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.Listing:
         r"""Updates an existing listing.
@@ -1276,7 +1289,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.UpdateListingRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.UpdateListingRequest, dict]]):
                 The request object. Message for updating a Listing.
             listing (:class:`google.cloud.bigquery_data_exchange_v1beta1.types.Listing`):
                 Required. The listing to update.
@@ -1356,11 +1369,11 @@ class AnalyticsHubServiceAsyncClient:
 
     async def delete_listing(
         self,
-        request: Union[dataexchange.DeleteListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.DeleteListingRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a listing.
@@ -1389,7 +1402,7 @@ class AnalyticsHubServiceAsyncClient:
                 await client.delete_listing(request=request)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.DeleteListingRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.DeleteListingRequest, dict]]):
                 The request object. Message for deleting a listing.
             name (:class:`str`):
                 Required. Resource name of the listing to delete. e.g.
@@ -1445,11 +1458,11 @@ class AnalyticsHubServiceAsyncClient:
 
     async def subscribe_listing(
         self,
-        request: Union[dataexchange.SubscribeListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.SubscribeListingRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.SubscribeListingResponse:
         r"""Subscribes to a listing.
@@ -1492,7 +1505,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.SubscribeListingRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_data_exchange_v1beta1.types.SubscribeListingRequest, dict]]):
                 The request object. Message for subscribing to a
                 listing.
             name (:class:`str`):
@@ -1559,10 +1572,10 @@ class AnalyticsHubServiceAsyncClient:
 
     async def get_iam_policy(
         self,
-        request: Union[iam_policy_pb2.GetIamPolicyRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.GetIamPolicyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Gets the IAM policy.
@@ -1595,7 +1608,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
+            request (Optional[Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]]):
                 The request object. Request message for `GetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1702,10 +1715,10 @@ class AnalyticsHubServiceAsyncClient:
 
     async def set_iam_policy(
         self,
-        request: Union[iam_policy_pb2.SetIamPolicyRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.SetIamPolicyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Sets the IAM policy.
@@ -1738,7 +1751,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
+            request (Optional[Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]]):
                 The request object. Request message for `SetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1845,10 +1858,10 @@ class AnalyticsHubServiceAsyncClient:
 
     async def test_iam_permissions(
         self,
-        request: Union[iam_policy_pb2.TestIamPermissionsRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.TestIamPermissionsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Returns the permissions that a caller has.
@@ -1882,7 +1895,7 @@ class AnalyticsHubServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
+            request (Optional[Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]]):
                 The request object. Request message for
                 `TestIamPermissions` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1928,10 +1941,10 @@ class AnalyticsHubServiceAsyncClient:
 
     async def get_location(
         self,
-        request: locations_pb2.GetLocationRequest = None,
+        request: Optional[locations_pb2.GetLocationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.Location:
         r"""Gets information about a location.
@@ -1982,10 +1995,10 @@ class AnalyticsHubServiceAsyncClient:
 
     async def list_locations(
         self,
-        request: locations_pb2.ListLocationsRequest = None,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.ListLocationsResponse:
         r"""Lists information about the supported locations for this service.
@@ -2041,14 +2054,9 @@ class AnalyticsHubServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-bigquery-data-exchange",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("AnalyticsHubServiceAsyncClient",)
