@@ -16,33 +16,47 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.bigquery_data_exchange_v1beta1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.bigquery_data_exchange_v1beta1.services.analytics_hub_service import (
-    pagers,
-)
-from google.cloud.bigquery_data_exchange_v1beta1.types import dataexchange
 from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
-from .transports.base import AnalyticsHubServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.bigquery_data_exchange_v1beta1.services.analytics_hub_service import (
+    pagers,
+)
+from google.cloud.bigquery_data_exchange_v1beta1.types import dataexchange
+
+from .transports.base import DEFAULT_CLIENT_INFO, AnalyticsHubServiceTransport
 from .transports.grpc import AnalyticsHubServiceGrpcTransport
 from .transports.grpc_asyncio import AnalyticsHubServiceGrpcAsyncIOTransport
 
@@ -63,7 +77,7 @@ class AnalyticsHubServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[AnalyticsHubServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -386,8 +400,8 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, AnalyticsHubServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, AnalyticsHubServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the analytics hub service client.
@@ -401,7 +415,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
             transport (Union[str, AnalyticsHubServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -431,6 +445,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -483,11 +498,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def list_data_exchanges(
         self,
-        request: Union[dataexchange.ListDataExchangesRequest, dict] = None,
+        request: Optional[Union[dataexchange.ListDataExchangesRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDataExchangesPager:
         r"""Lists all data exchanges in a given project and
@@ -599,11 +614,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def list_org_data_exchanges(
         self,
-        request: Union[dataexchange.ListOrgDataExchangesRequest, dict] = None,
+        request: Optional[Union[dataexchange.ListOrgDataExchangesRequest, dict]] = None,
         *,
-        organization: str = None,
+        organization: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOrgDataExchangesPager:
         r"""Lists all data exchanges from projects in a given
@@ -720,11 +735,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def get_data_exchange(
         self,
-        request: Union[dataexchange.GetDataExchangeRequest, dict] = None,
+        request: Optional[Union[dataexchange.GetDataExchangeRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.DataExchange:
         r"""Gets the details of a data exchange.
@@ -824,12 +839,12 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def create_data_exchange(
         self,
-        request: Union[dataexchange.CreateDataExchangeRequest, dict] = None,
+        request: Optional[Union[dataexchange.CreateDataExchangeRequest, dict]] = None,
         *,
-        parent: str = None,
-        data_exchange: dataexchange.DataExchange = None,
+        parent: Optional[str] = None,
+        data_exchange: Optional[dataexchange.DataExchange] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.DataExchange:
         r"""Creates a new data exchange.
@@ -944,12 +959,12 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def update_data_exchange(
         self,
-        request: Union[dataexchange.UpdateDataExchangeRequest, dict] = None,
+        request: Optional[Union[dataexchange.UpdateDataExchangeRequest, dict]] = None,
         *,
-        data_exchange: dataexchange.DataExchange = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        data_exchange: Optional[dataexchange.DataExchange] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.DataExchange:
         r"""Updates an existing data exchange.
@@ -1066,11 +1081,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def delete_data_exchange(
         self,
-        request: Union[dataexchange.DeleteDataExchangeRequest, dict] = None,
+        request: Optional[Union[dataexchange.DeleteDataExchangeRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an existing data exchange.
@@ -1157,11 +1172,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def list_listings(
         self,
-        request: Union[dataexchange.ListListingsRequest, dict] = None,
+        request: Optional[Union[dataexchange.ListListingsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListListingsPager:
         r"""Lists all listings in a given project and location.
@@ -1272,11 +1287,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def get_listing(
         self,
-        request: Union[dataexchange.GetListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.GetListingRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.Listing:
         r"""Gets the details of a listing.
@@ -1377,12 +1392,12 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def create_listing(
         self,
-        request: Union[dataexchange.CreateListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.CreateListingRequest, dict]] = None,
         *,
-        parent: str = None,
-        listing: dataexchange.Listing = None,
+        parent: Optional[str] = None,
+        listing: Optional[dataexchange.Listing] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.Listing:
         r"""Creates a new listing.
@@ -1495,12 +1510,12 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def update_listing(
         self,
-        request: Union[dataexchange.UpdateListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.UpdateListingRequest, dict]] = None,
         *,
-        listing: dataexchange.Listing = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        listing: Optional[dataexchange.Listing] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.Listing:
         r"""Updates an existing listing.
@@ -1615,11 +1630,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def delete_listing(
         self,
-        request: Union[dataexchange.DeleteListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.DeleteListingRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a listing.
@@ -1704,11 +1719,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def subscribe_listing(
         self,
-        request: Union[dataexchange.SubscribeListingRequest, dict] = None,
+        request: Optional[Union[dataexchange.SubscribeListingRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.SubscribeListingResponse:
         r"""Subscribes to a listing.
@@ -1818,10 +1833,10 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def get_iam_policy(
         self,
-        request: Union[iam_policy_pb2.GetIamPolicyRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.GetIamPolicyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Gets the IAM policy.
@@ -1960,10 +1975,10 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def set_iam_policy(
         self,
-        request: Union[iam_policy_pb2.SetIamPolicyRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.SetIamPolicyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Sets the IAM policy.
@@ -2102,10 +2117,10 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def test_iam_permissions(
         self,
-        request: Union[iam_policy_pb2.TestIamPermissionsRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.TestIamPermissionsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Returns the permissions that a caller has.
@@ -2197,10 +2212,10 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def get_location(
         self,
-        request: locations_pb2.GetLocationRequest = None,
+        request: Optional[locations_pb2.GetLocationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.Location:
         r"""Gets information about a location.
@@ -2251,10 +2266,10 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
     def list_locations(
         self,
-        request: locations_pb2.ListLocationsRequest = None,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.ListLocationsResponse:
         r"""Lists information about the supported locations for this service.
@@ -2304,14 +2319,9 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         return response
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-bigquery-data-exchange",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("AnalyticsHubServiceClient",)
